#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 servant-client
version:              0.18.2
visibility:           public
id:                   servant-client-0.18.2-I9C0Cy2YGbR2G9HxaeOyxu
key:                  servant-client-0.18.2-I9C0Cy2YGbR2G9HxaeOyxu
license:              BSD-3-Clause
copyright:
    2014-2016 Zalora South East Asia Pte Ltd, 2016-2019 Servant Contributors

maintainer:           haskell-servant-maintainers@googlegroups.com
author:               Servant Contributors
homepage:             http://docs.servant.dev/
synopsis:             Automatic derivation of querying functions for servant
description:
    This library lets you derive automatically Haskell functions that
    let you query each endpoint of a <http://hackage.haskell.org/package/servant servant> webservice.

    See <http://docs.servant.dev/en/stable/tutorial/Client.html the client section of the tutorial>.

    <https://github.com/haskell-servant/servant/blob/master/servant-client/CHANGELOG.md CHANGELOG>

category:             Servant, Web
abi:                  4e6f11830b7c45caf565e287a4704511
exposed:              True
exposed-modules:
    Servant.Client Servant.Client.Internal.HttpClient
    Servant.Client.Internal.HttpClient.Streaming
    Servant.Client.Streaming

import-dirs:          /usr/lib/ghc-8.10.5/site-local/servant-client-0.18.2
library-dirs:         /usr/lib/ghc-8.10.5/site-local/servant-client-0.18.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/i386-linux-ghc-8.10.5/servant-client-0.18.2
hs-libraries:         HSservant-client-0.18.2-I9C0Cy2YGbR2G9HxaeOyxu
depends:
    base-4.14.2.0 base-compat-0.11.2-Eyusxyk2CrTGloLdon9bIK
    bytestring-0.10.12.0 containers-0.6.4.1 deepseq-1.4.4.0
    exceptions-0.10.4 http-client-0.7.8-C6JWYZrbeBCPAdb6EpQD6
    http-media-0.8.0.0-BMdtrV6lKwm8BrbHWDmj81
    http-types-0.12.3-JSCBEGU6f6MIPS3hXwEPIB
    kan-extensions-5.2.2-1PmOluKXwVMK6mNNf9COcY
    monad-control-1.0.2.3-Bi4GOATU8bxGtDgK1rR68J mtl-2.2.2
    semigroupoids-5.3.5-CXCAmgAqO2AH1F4bh8bCjo
    servant-0.18.2-A7hwreQE0UjKrPObUkIw0l
    servant-client-core-0.18.2-4SD0xOG9RwvJmhtKvXNGRN stm-2.5.0.1
    text-1.2.4.1 time-1.9.3 transformers-0.5.6.2
    transformers-base-0.4.5.2-KzHjyAKDkdpHt6juu1Rjxn
    transformers-compat-0.6.6-8xD7tdhdla21VYsnm1hEvk

haddock-interfaces:
    /usr/share/doc/haskell-servant-client/html/servant-client.haddock

haddock-html:         /usr/share/doc/haskell-servant-client/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

